summaryrefslogtreecommitdiffstats
path: root/lib/kofficecore/KoView.h
diff options
context:
space:
mode:
Diffstat (limited to 'lib/kofficecore/KoView.h')
-rw-r--r--lib/kofficecore/KoView.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/lib/kofficecore/KoView.h b/lib/kofficecore/KoView.h
index 42d78fb6..93eb8971 100644
--- a/lib/kofficecore/KoView.h
+++ b/lib/kofficecore/KoView.h
@@ -68,12 +68,12 @@ public:
*
* @param document is the document which should be displayed in this view. This pointer
* must not be zero.
* @param tqparent tqparent widget for this view.
* @param name Name of the view. The name is used in DCOP, so the name should
* match the pattern [A-Za-z_][A-Za-z_0-9]*.
*
*/
- KoView( KoDocument *document, TQWidget *tqparent = 0, const char *name = 0 );
+ KoView( KoDocument *document, TQWidget *parent = 0, const char *name = 0 );
/**
* Destroys the view and unregisters at the document.
*/
@@ -68,12 +68,12 @@ public:
* @param document is the document which should be displayed in this view. This pointer
* must not be zero.
- * @param tqparent tqparent widget for this view.
+ * @param parent parent widget for this view.
* @param name Name of the view. The name is used in DCOP, so the name should
* match the pattern [A-Za-z_][A-Za-z_0-9]*.